@@ -12,7 +12,7 @@
 #' @examples
 #' create_fig_sed(score = 400)
 #' 
-create_fig_sed <- function(score, language = c("en", "fr")) {
+create_fig_sed <- function(score, language = c("en", "fr", "de")) {
   
 language <- match.arg(language)
   
@@ -121,6 +121,48 @@ if (language == "fr" && score/60 >= 6 && score/60 <= 12) {
   
 }
   
+  if (language == "de" && score/60 >= 6 && score/60 <= 12) { 
+    
+    g_sed <-
+      ggplot() +
+      geom_rect(data = grid_sed, aes(xmin = 6, xmax = 12, ymin = 0.5,  ymax = 3.1), fill = "white", color = "grey50") + 
+      geom_line(data = grid_sed, aes (x = x, y = mid), linewidth = 1, colour = "#3366FF") +
+      geom_point(data = score_sed, aes(x = 7.5, y = 1), shape = 21, colour = "#3366FF", fill = "grey95", size = 5, stroke = 1.5) +
+      geom_point(data = score_sed, aes(x = x, y = pred), color = "red", size = 7, shape = 1) +
+      geom_point(data = score_sed, aes(x = x, y = pred), color = "red", size = 4, shape = 16) +
+      geom_point(data = score_sed, aes(x = x, y = pred), color = "red", size = 7, shape = 3) +
+      scale_y_continuous(trans = scales::log2_trans()) +
+      scale_x_continuous(limits = c(1, 15), breaks = seq(6, 12, 1)) +
+      coord_cartesian(xlim = c(6, 12), ylim = c(0.5, 3.1), expand = FALSE, clip = "off") +
+      labs(title = "Sterblichkeitsrisiko vs. SED Stunden/Tag", x = "", y = NULL) +
+      theme_bw() +
+      theme(axis.ticks = element_blank(),
+            axis.text.x = element_text(size = 13),
+            axis.text.y = element_blank(),
+            legend.position = "none",
+            legend.title = element_text(face = "bold" , size = 10),
+            panel.grid.major = element_blank(),
+            panel.grid.minor = element_blank(),
+            plot.background = element_rect(fill = "beige", color = "beige"),
+            plot.margin = margin(1, 1, 0, 1, "cm"),
+            plot.title = element_text(size = 15, color = "grey30", face = "bold")) +
+      annotate("text", label = "Die Kurve zeigt den \nmortality hazard ratio bei  \nadults, die \xc3\xa4lter als 40 \nJahre alt sind.", 
+               x = 9.4, y = 0.85, hjust = 0, 
+               fontface = "bold.italic", colour = "#3366FF") +
+      annotate(geom = "curve", 
+               x = 9.35, 
+               y = 0.85, 
+               xend = 8.9, 
+               yend = 1.10, 
+               curvature = -.35, arrow = arrow(length = unit(2, "mm")),
+               colour = "#3366FF") +
+      annotate("text", label = "Ref: Ekelund et al. BMJ 2019, l4570 (angepasst)", hjust = 0, x = 6.1, y = 0.54) +
+      annotate("text", label = "Referenzpunkt", hjust = 1, vjust = 0, x = 7.45, y = 1.13, color = "grey30", fontface = "bold")
+    
+    return(g_sed)
+    
+  }
+  
   
   if (language == "en" && (score/60 < 6 | score/60 > 12)) { 
     
@@ -203,5 +245,46 @@ if (language == "fr" && score/60 >= 6 && score/60 <= 12) {
     return(g_sed)
     
   }
+  
+  if (language == "de" && (score/60 < 6 | score/60 > 12)) { 
+    
+    g_sed <-
+      ggplot() +
+      geom_rect(data = grid_sed, aes(xmin = 6, xmax = 12, ymin = 0.5,  ymax = 3.1), fill = "white", color = "grey50") + 
+      geom_line(data = grid_sed, aes (x = x, y = mid), linewidth = 1, colour = "#3366FF") +
+      geom_point(data = score_sed, aes(x = 7.5, y = 1), shape = 21, colour = "#3366FF", fill = "grey95", size = 5, stroke = 1.5) +
+      scale_y_continuous(trans = scales::log2_trans()) +
+      scale_x_continuous(limits = c(1, 15), breaks = seq(6, 12, 1)) +
+      coord_cartesian(xlim = c(6, 12), ylim = c(0.5, 3.1), expand = FALSE, clip = "off") +
+      labs(title = "Sterblichkeitsrisiko vs. SED Stunden/Tag", x = "", y = NULL) +
+      theme_bw() +
+      theme(axis.ticks = element_blank(),
+            axis.text.x = element_text(size = 13),
+            axis.text.y = element_blank(),
+            legend.position = "none",
+            legend.title = element_text(face = "bold" , size = 10),
+            panel.grid.major = element_blank(),
+            panel.grid.minor = element_blank(),
+            plot.background = element_rect(fill = "beige", color = "beige"),
+            plot.margin = margin(1, 1, 0, 1, "cm"),
+            plot.title = element_text(size = 15, color = "grey30", face = "bold")) +
+      annotate("text", label = "Die Kurve zeigt den \nmortality hazard ratio bei  \nadults, die \xc3\xa4lter als 40 \nJahre alt sind.", 
+               x = 9.4, y = 0.85, hjust = 0, 
+               fontface = "bold.italic", colour = "#3366FF") +
+      annotate(geom = "curve", 
+               x = 9.35, 
+               y = 0.85, 
+               xend = 8.9, 
+               yend = 1.10, 
+               curvature = -.35, arrow = arrow(length = unit(2, "mm")),
+               colour = "#3366FF") +
+      annotate("text", label = "Ref: Ekelund et al. BMJ 2019, l4570 (angepasst)", hjust = 0, x = 6.1, y = 0.54) +
+      annotate("text", label = "Referenzpunkt", hjust = 1, vjust = 0, x = 7.45, y = 1.13, color = "grey30", fontface = "bold") +
+      annotate("text", label = "Der ermittelte Wert liegt \xc3\xbcber dem oberen \nlimit der X-Achse der urspr\xc3\xbcnglichen \nAbbildung.", 
+               hjust = 0, vjust = 1, x = 6.5, y = 2.9, size = 4, color = "red", fontface = "bold")
+    
+    return(g_sed)
+    
+  }
 }
 
