@@ -65,17 +65,31 @@ plot_data_with_intensity <- function(
     zoom_to = "23:59:59"
     ){
 
+  # Setting parameters for computation of axis breaks labels
+  if (as.numeric(hms::as_hms(zoom_to)) - as.numeric(hms::as_hms(zoom_from)) < 2*3600) {
+    breaks_control_1 = hms::hms(0)
+    breaks_control_2 = hms::hms(0)
+    breaks_control_3 = 3600/2
+  } else {
+    breaks_control_1 = hms::hms(3600)
+    breaks_control_2 = hms::hms(3599)
+    breaks_control_3 = 2*3600
+  }
+  
   # Setting the format of the time variable
     format_hm <- function(sec) stringr::str_sub(format(sec), end = -4L)
     date_labs <- format(data$date, "%d-%m-%y")
     names(date_labs) <- data$days
     
+  # Getting epoch length
+    epoch <- as.numeric(data[[col_time]][2] - data[[col_time]][1])
+    
   # Creating the plot
     p <-
     ggplot(data = data %>% dplyr::filter(.data[[col_time]] >= hms::as_hms(zoom_from) & .data[[col_time]] <= hms::as_hms(zoom_to))) +
     geom_rect(aes(
-      xmin = time, 
-      xmax =  time + hms::as_hms(60), 
+      xmin = .data[[col_time]], 
+      xmax =  .data[[col_time]] + hms::as_hms(epoch), 
       ymin = -Inf, 
       ymax = Inf, 
       color = intensity_category,
@@ -104,15 +118,15 @@ plot_data_with_intensity <- function(
       ) +
    scale_x_time(
      limits = c(hms::as_hms(zoom_from), hms::as_hms(zoom_to)),
-     breaks = hms::hms(seq(as.numeric(hms::as_hms(zoom_from)), as.numeric(hms::as_hms(zoom_to)), 2*3600)), 
+     breaks = hms::hms(seq(as.numeric(hms::as_hms(zoom_from) + breaks_control_1), as.numeric(hms::as_hms(zoom_to) - breaks_control_2), breaks_control_3)), 
      expand = c(0, 0), 
      labels = format_hm
      ) +
    scale_y_continuous(position = "right", expand = c(0, 0)) +
    scale_fill_manual(breaks = c("Nonwear", "SED", "LPA", "MVPA"), values = c("lemonchiffon3", "#3F51B5", "#FFFF33", "#FF0066")) +
    scale_color_manual(breaks = c("Nonwear", "SED", "LPA", "MVPA"), values = c("lemonchiffon3", "#3F51B5", "#FFFF33", "#FF0066")) +
-   labs(x = "Time (hh:mm)", y = metric, fill = "", color = "") +
-   theme_bw() +
+      labs(x = "Time (hh:mm)", y = paste0(metric, "/", epoch, "s"), fill = "", color = "") +
+  theme_bw() +
    theme(legend.position = "bottom",
          legend.key = element_rect(color = "grey"),
          panel.grid.major = element_blank(), 
